sqlobject.tests.test_basic module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_basic module

class `sqlobject.tests.test_basic.` `SOTestSO1`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test_s_o1
  property `name`
  property `passwd`
  `q` = so_test_s_o1
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `cacheValues` = False
    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_basic.SOTestSO1`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_s_o1'

class `sqlobject.tests.test_basic.` `SOTestSO10`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test_s_o10
  property `name`
  `q` = so_test_s_o10
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_basic.SOTestSO10`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_s_o10'

class `sqlobject.tests.test_basic.` `SOTestSO11`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test_s_o11
  property `name`
  property `other`
  property `otherID`
  `q` = so_test_s_o11
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_basic.SOTestSO11`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_s_o11'

class `sqlobject.tests.test_basic.` `SOTestSO12`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test_s_o12
  property `name`
  `q` = so_test_s_o12
  property `so_value`
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_basic.SOTestSO12`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_s_o12'

class `sqlobject.tests.test_basic.` `SOTestSO2`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test_s_o2
  property `name`
  property `passwd`
  `q` = so_test_s_o2
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_basic.SOTestSO2`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_s_o2'

class `sqlobject.tests.test_basic.` `SOTestSO3`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test_s_o3
  property `name`
  property `other`
  property `other2`
  property `other2ID`
  property `otherID`
  `q` = so_test_s_o3
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_basic.SOTestSO3`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_s_o3'

class `sqlobject.tests.test_basic.` `SOTestSO4`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test_s_o4
  property `me`
  `q` = so_test_s_o4
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_basic.SOTestSO4`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_s_o4'

class `sqlobject.tests.test_basic.` `SOTestSO5`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `another`
  property `anotherID`
  `j` = so_test_s_o5
  property `name`
  property `other`
  property `otherID`
  `q` = so_test_s_o5
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_basic.SOTestSO5`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_s_o5'

class `sqlobject.tests.test_basic.` `SOTestSO6`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test_s_o6
  property `name`
  property `other`
  property `otherID`
  `q` = so_test_s_o6
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_basic.SOTestSO6`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_s_o6'

class `sqlobject.tests.test_basic.` `SOTestSO7`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test_s_o7
  property `name`
  `q` = so_test_s_o7
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_basic.SOTestSO7`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_s_o7'

class `sqlobject.tests.test_basic.` `SOTestSO8`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test_s_o8
  property `name`
  property `other`
  property `otherID`
  `q` = so_test_s_o8
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_basic.SOTestSO8`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_s_o8'

class `sqlobject.tests.test_basic.` `SOTestSO9`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test_s_o9
  property `name`
  `q` = so_test_s_o9
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_basic.SOTestSO9`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_s_o9'

class `sqlobject.tests.test_basic.` `Student`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `is_smart`
  `j` = student
  `q` = student
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_basic.Student`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'student'

`sqlobject.tests.test_basic.` `setupGetters`(cls)

`sqlobject.tests.test_basic.` `testAsDict`()

`sqlobject.tests.test_basic.` `testForeignKeyDestroySelfRestrict`()

`sqlobject.tests.test_basic.` `testForeignKeyDropTableCascade`()

`sqlobject.tests.test_basic.` `testForeignKeySetNull`()

`sqlobject.tests.test_basic.` `test_boolCol`()

`sqlobject.tests.test_basic.` `test_case1`()

`sqlobject.tests.test_basic.` `test_case2`()

`sqlobject.tests.test_basic.` `test_connection_override`()

`sqlobject.tests.test_basic.` `test_count`()

`sqlobject.tests.test_basic.` `test_defaultSQL`()

`sqlobject.tests.test_basic.` `test_extra_vars`()

`sqlobject.tests.test_basic.` `test_foreignKey`()

`sqlobject.tests.test_basic.` `test_foreignKeyDestroySelfCascade`()

`sqlobject.tests.test_basic.` `test_getset`()

`sqlobject.tests.test_basic.` `test_newline`()

`sqlobject.tests.test_basic.` `test_nonexisting_attr`()

`sqlobject.tests.test_basic.` `test_selectBy`()